#
# PySNMP MIB module RADIUS-AUTH-SERVER-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/RADIUS-AUTH-SERVER-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:25:34 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueSizeConstraint, ConstraintsUnion, ConstraintsIntersection, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ConstraintsIntersection", "ValueRangeConstraint")
( InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetAddressType")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( Integer32, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, ObjectIdentity, Counter64, Counter32, iso, MibIdentifier, TimeTicks, NotificationType, IpAddress, mib_2, Gauge32, ModuleIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "ObjectIdentity", "Counter64", "Counter32", "iso", "MibIdentifier", "TimeTicks", "NotificationType", "IpAddress", "mib-2", "Gauge32", "ModuleIdentity")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
radiusAuthServMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 67, 1, 1)).setRevisions(("2006-08-21 00:00", "1999-06-11 00:00",))
if mibBuilder.loadTexts: radiusAuthServMIB.setLastUpdated('200608210000Z')
if mibBuilder.loadTexts: radiusAuthServMIB.setOrganization('IETF RADIUS Extensions Working Group.')
if mibBuilder.loadTexts: radiusAuthServMIB.setContactInfo(' Bernard Aboba\n                Microsoft\n                One Microsoft Way\n                Redmond, WA  98052\n                US\n                Phone: +1 425 936 6605\n\n                EMail: bernarda@microsoft.com')
if mibBuilder.loadTexts: radiusAuthServMIB.setDescription('The MIB module for entities implementing the server\n              side of the Remote Authentication Dial-In User\n              Service (RADIUS) authentication protocol.  Copyright\n              (C) The Internet Society (2006).  This version of this\n              MIB module is part of RFC 4669; see the RFC itself for\n              full legal notices.')
radiusMIB = ObjectIdentity((1, 3, 6, 1, 2, 1, 67))
if mibBuilder.loadTexts: radiusMIB.setDescription('The OID assigned to RADIUS MIB work by the IANA.')
radiusAuthentication = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1))
radiusAuthServMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1, 1, 1))
radiusAuthServ = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1))
radiusAuthServIdent = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 1), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServIdent.setDescription("The implementation identification string for the\n              RADIUS authentication server software in use on the\n              system, for example, 'FNS-2.1'.")
radiusAuthServUpTime = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 2), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServUpTime.setDescription('If the server has a persistent state (e.g., a\n              process), this value will be the time elapsed (in\n              hundredths of a second) since the server process\n              was started.  For software without persistent state,\n              this value will be zero.')
radiusAuthServResetTime = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 3), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServResetTime.setDescription("If the server has a persistent state (e.g., a process)\n              and supports a 'reset' operation (e.g., can be told to\n              re-read configuration files), this value will be the\n              time elapsed (in hundredths of a second) since the\n              server was 'reset.'  For software that does not\n              have persistence or does not support a 'reset'\n              operation, this value will be zero.")
radiusAuthServConfigReset = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("reset", 2), ("initializing", 3), ("running", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: radiusAuthServConfigReset.setDescription('Status/action object to reinitialize any persistent\n               server state.  When set to reset(2), any persistent\n               server state (such as a process) is reinitialized as\n               if the server had just been started.  This value will\n               never be returned by a read operation.  When read,\n               one of the following values will be returned:\n                   other(1) - server in some unknown state;\n                   initializing(3) - server (re)initializing;\n                   running(4) - server currently running.')
radiusAuthServTotalAccessRequests = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 5), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServTotalAccessRequests.setDescription('The number of packets received on the\n\n                authentication port.')
radiusAuthServTotalInvalidRequests = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 6), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServTotalInvalidRequests.setDescription('The number of RADIUS Access-Request packets\n               received from unknown addresses.')
radiusAuthServTotalDupAccessRequests = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 7), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServTotalDupAccessRequests.setDescription('The number of duplicate RADIUS Access-Request\n              packets received.')
radiusAuthServTotalAccessAccepts = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 8), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServTotalAccessAccepts.setDescription('The number of RADIUS Access-Accept packets sent.')
radiusAuthServTotalAccessRejects = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 9), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServTotalAccessRejects.setDescription('The number of RADIUS Access-Reject packets sent.')
radiusAuthServTotalAccessChallenges = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 10), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServTotalAccessChallenges.setDescription('The number of RADIUS Access-Challenge packets sent.')
radiusAuthServTotalMalformedAccessRequests = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 11), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServTotalMalformedAccessRequests.setDescription('The number of malformed RADIUS Access-Request\n             packets received.  Bad authenticators\n             and unknown types are not included as\n             malformed Access-Requests.')
radiusAuthServTotalBadAuthenticators = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 12), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServTotalBadAuthenticators.setDescription('The number of RADIUS Authentication-Request packets\n             that contained invalid Message Authenticator\n             attributes received.')
radiusAuthServTotalPacketsDropped = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 13), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServTotalPacketsDropped.setDescription('The number of incoming packets\n             silently discarded for some reason other\n             than malformed, bad authenticators or\n             unknown types.')
radiusAuthServTotalUnknownTypes = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 14), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServTotalUnknownTypes.setDescription('The number of RADIUS packets of unknown type that\n             were received.')
radiusAuthClientTable = MibTable((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15), )
if mibBuilder.loadTexts: radiusAuthClientTable.setDescription('The (conceptual) table listing the RADIUS\n              authentication clients with which the server shares\n              a secret.')
radiusAuthClientEntry = MibTableRow((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1), ).setIndexNames((0, "RADIUS-AUTH-SERVER-MIB", "radiusAuthClientIndex"))
if mibBuilder.loadTexts: radiusAuthClientEntry.setDescription('An entry (conceptual row) representing a RADIUS\n              authentication client with which the server shares a\n              secret.')
radiusAuthClientIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: radiusAuthClientIndex.setDescription('A number uniquely identifying each RADIUS\n              authentication client with which this server\n              communicates.')
radiusAuthClientAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientAddress.setDescription('The NAS-IP-Address of the RADIUS authentication client\n              referred to in this table entry.')
radiusAuthClientID = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 3), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientID.setDescription('The NAS-Identifier of the RADIUS authentication client\n              referred to in this table entry.  This is not\n              necessarily the same as sysName in MIB II.')
radiusAuthServAccessRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 4), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServAccessRequests.setDescription('The number of packets received on the authentication\n\n              port from this client.')
radiusAuthServDupAccessRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 5), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServDupAccessRequests.setDescription('The number of duplicate RADIUS Access-Request\n              packets received from this client.')
radiusAuthServAccessAccepts = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 6), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServAccessAccepts.setDescription('The number of RADIUS Access-Accept packets\n              sent to this client.')
radiusAuthServAccessRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 7), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServAccessRejects.setDescription('The number of RADIUS Access-Reject packets\n              sent to this client.')
radiusAuthServAccessChallenges = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 8), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServAccessChallenges.setDescription('The number of RADIUS Access-Challenge packets\n              sent to this client.')
radiusAuthServMalformedAccessRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 9), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServMalformedAccessRequests.setDescription('The number of malformed RADIUS Access-Request\n              packets received from this client.\n              Bad authenticators and unknown types are not included\n              as malformed Access-Requests.')
radiusAuthServBadAuthenticators = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 10), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServBadAuthenticators.setDescription('The number of RADIUS Authentication-Request packets\n              that contained invalid Message Authenticator\n              attributes received from this client.')
radiusAuthServPacketsDropped = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 11), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServPacketsDropped.setDescription('The number of incoming packets from this\n               client silently discarded for some reason other\n               than malformed, bad authenticators or\n               unknown types.')
radiusAuthServUnknownTypes = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 15, 1, 12), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServUnknownTypes.setDescription('The number of RADIUS packets of unknown type that\n              were received from this client.')
radiusAuthClientExtTable = MibTable((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16), )
if mibBuilder.loadTexts: radiusAuthClientExtTable.setDescription('The (conceptual) table listing the RADIUS\n              authentication clients with which the server shares\n              a secret.')
radiusAuthClientExtEntry = MibTableRow((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1), ).setIndexNames((0, "RADIUS-AUTH-SERVER-MIB", "radiusAuthClientExtIndex"))
if mibBuilder.loadTexts: radiusAuthClientExtEntry.setDescription('An entry (conceptual row) representing a RADIUS\n              authentication client with which the server shares a\n              secret.')
radiusAuthClientExtIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: radiusAuthClientExtIndex.setDescription('A number uniquely identifying each RADIUS\n              authentication client with which this server\n              communicates.')
radiusAuthClientInetAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 2), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientInetAddressType.setDescription('The type of address format used for the\n                radiusAuthClientInetAddress object.')
radiusAuthClientInetAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 3), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientInetAddress.setDescription('The IP address of the RADIUS authentication\n                client referred to in this table entry, using\n                the version-neutral IP address format.')
radiusAuthClientExtID = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 4), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtID.setDescription('The NAS-Identifier of the RADIUS authentication client\n              referred to in this table entry.  This is not\n              necessarily the same as sysName in MIB II.')
radiusAuthServExtAccessRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 5), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServExtAccessRequests.setDescription('The number of packets received on the authentication\n              port from this client.  This counter may experience a\n              discontinuity when the RADIUS Server module within the\n              managed entity is reinitialized, as indicated by the\n              current value of radiusAuthServCounterDiscontinuity.')
radiusAuthServExtDupAccessRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 6), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServExtDupAccessRequests.setDescription('The number of duplicate RADIUS Access-Request\n              packets received from this client.  This counter may\n              experience a discontinuity when the RADIUS Server\n              module within the managed entity is reinitialized, as\n              indicated by the current value of\n              radiusAuthServCounterDiscontinuity.')
radiusAuthServExtAccessAccepts = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 7), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServExtAccessAccepts.setDescription('The number of RADIUS Access-Accept packets\n              sent to this client.  This counter may experience a\n              discontinuity when the RADIUS Server module within the\n              managed entity is reinitialized, as indicated by the\n              current value of radiusAuthServCounterDiscontinuity.')
radiusAuthServExtAccessRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 8), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServExtAccessRejects.setDescription('The number of RADIUS Access-Reject packets\n              sent to this client.  This counter may experience a\n              discontinuity when the RADIUS Server module within the\n\n              managed entity is reinitialized, as indicated by the\n              current value of radiusAuthServCounterDiscontinuity.')
radiusAuthServExtAccessChallenges = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 9), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServExtAccessChallenges.setDescription('The number of RADIUS Access-Challenge packets\n              sent to this client.  This counter may experience a\n              discontinuity when the RADIUS Server module within the\n              managed entity is reinitialized, as indicated by the\n              current value of radiusAuthServCounterDiscontinuity.')
radiusAuthServExtMalformedAccessRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 10), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServExtMalformedAccessRequests.setDescription('The number of malformed RADIUS Access-Request\n              packets received from this client.  Bad authenticators\n              and unknown types are not included as malformed\n              Access-Requests.  This counter may experience a\n              discontinuity when the RADIUS Server module within the\n              managed entity is reinitialized, as indicated by the\n              current value of radiusAuthServCounterDiscontinuity.')
radiusAuthServExtBadAuthenticators = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 11), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServExtBadAuthenticators.setDescription('The number of RADIUS Authentication-Request packets\n              that contained invalid Message Authenticator\n              attributes received from this client.  This counter\n              may experience a discontinuity when the RADIUS Server\n              module within the managed entity is reinitialized, as\n              indicated by the current value of\n              radiusAuthServCounterDiscontinuity.')
radiusAuthServExtPacketsDropped = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 12), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServExtPacketsDropped.setDescription('The number of incoming packets from this client\n              silently discarded for some reason other than\n              malformed, bad authenticators or unknown types.\n              This counter may experience a discontinuity when the\n              RADIUS Server module within the managed entity is\n              reinitialized, as indicated by the current value of\n              radiusAuthServCounterDiscontinuity.')
radiusAuthServExtUnknownTypes = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 13), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServExtUnknownTypes.setDescription('The number of RADIUS packets of unknown type that\n              were received from this client.  This counter may\n              experience a discontinuity when the RADIUS Server\n              module within the managed entity is reinitialized, as\n              indicated by the current value of\n              radiusAuthServCounterDiscontinuity.')
radiusAuthServCounterDiscontinuity = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 1, 1, 1, 16, 1, 14), TimeTicks()).setUnits('centiseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServCounterDiscontinuity.setDescription('The number of centiseconds since the last\n                discontinuity in the RADIUS Server counters.\n                A discontinuity may be the result of a\n                reinitialization of the RADIUS Server module\n                within the managed entity.')
radiusAuthServMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1, 1, 2))
radiusAuthServMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1, 1, 2, 1))
radiusAuthServMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1, 1, 2, 2))
radiusAuthServMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 67, 1, 1, 2, 1, 1)).setObjects(*(("RADIUS-AUTH-SERVER-MIB", "radiusAuthServMIBGroup"),))
if mibBuilder.loadTexts: radiusAuthServMIBCompliance.setDescription('The compliance statement for authentication\n                   servers implementing the RADIUS Authentication\n                   Server MIB.  Implementation of this module is for\n                   IPv4-only entities, or for backwards compatibility\n                   use with entities that support both IPv4 and\n                   IPv6.')
radiusAuthServMIBExtCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 67, 1, 1, 2, 1, 2)).setObjects(*(("RADIUS-AUTH-SERVER-MIB", "radiusAuthServExtMIBGroup"),))
if mibBuilder.loadTexts: radiusAuthServMIBExtCompliance.setDescription('The compliance statement for authentication\n                   servers implementing the RADIUS Authentication\n                   Server IPv6 Extensions MIB.  Implementation of\n                   this module is for entities that support IPv6,\n                   or support IPv4 and IPv6.')
radiusAuthServMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 67, 1, 1, 2, 2, 1)).setObjects(*(("RADIUS-AUTH-SERVER-MIB", "radiusAuthServIdent"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServUpTime"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServResetTime"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServConfigReset"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalInvalidRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalDupAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalAccessAccepts"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalAccessRejects"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalAccessChallenges"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalMalformedAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalBadAuthenticators"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalPacketsDropped"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalUnknownTypes"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthClientAddress"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthClientID"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServDupAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServAccessAccepts"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServAccessRejects"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServAccessChallenges"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServMalformedAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServBadAuthenticators"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServPacketsDropped"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServUnknownTypes"),))
if mibBuilder.loadTexts: radiusAuthServMIBGroup.setDescription('The collection of objects providing management of\n             a RADIUS Authentication Server.')
radiusAuthServExtMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 67, 1, 1, 2, 2, 2)).setObjects(*(("RADIUS-AUTH-SERVER-MIB", "radiusAuthServIdent"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServUpTime"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServResetTime"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServConfigReset"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalInvalidRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalDupAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalAccessAccepts"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalAccessRejects"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalAccessChallenges"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalMalformedAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalBadAuthenticators"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalPacketsDropped"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServTotalUnknownTypes"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthClientInetAddressType"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthClientInetAddress"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthClientExtID"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServExtAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServExtDupAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServExtAccessAccepts"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServExtAccessRejects"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServExtAccessChallenges"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServExtMalformedAccessRequests"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServExtBadAuthenticators"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServExtPacketsDropped"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServExtUnknownTypes"), ("RADIUS-AUTH-SERVER-MIB", "radiusAuthServCounterDiscontinuity"),))
if mibBuilder.loadTexts: radiusAuthServExtMIBGroup.setDescription('The collection of objects providing management of\n             a RADIUS Authentication Server.')
mibBuilder.exportSymbols("RADIUS-AUTH-SERVER-MIB", PYSNMP_MODULE_ID=radiusAuthServMIB, radiusAuthServExtMalformedAccessRequests=radiusAuthServExtMalformedAccessRequests, radiusAuthServAccessRejects=radiusAuthServAccessRejects, radiusAuthServMIB=radiusAuthServMIB, radiusAuthClientExtIndex=radiusAuthClientExtIndex, radiusAuthServMIBCompliances=radiusAuthServMIBCompliances, radiusAuthServTotalBadAuthenticators=radiusAuthServTotalBadAuthenticators, radiusAuthServCounterDiscontinuity=radiusAuthServCounterDiscontinuity, radiusAuthServMIBObjects=radiusAuthServMIBObjects, radiusAuthServTotalAccessRejects=radiusAuthServTotalAccessRejects, radiusAuthServTotalMalformedAccessRequests=radiusAuthServTotalMalformedAccessRequests, radiusAuthClientID=radiusAuthClientID, radiusAuthServUnknownTypes=radiusAuthServUnknownTypes, radiusAuthClientInetAddressType=radiusAuthClientInetAddressType, radiusAuthServTotalInvalidRequests=radiusAuthServTotalInvalidRequests, radiusAuthServTotalPacketsDropped=radiusAuthServTotalPacketsDropped, radiusAuthServAccessChallenges=radiusAuthServAccessChallenges, radiusAuthClientExtTable=radiusAuthClientExtTable, radiusAuthServExtAccessAccepts=radiusAuthServExtAccessAccepts, radiusAuthServMIBCompliance=radiusAuthServMIBCompliance, radiusAuthServExtAccessRequests=radiusAuthServExtAccessRequests, radiusAuthServExtUnknownTypes=radiusAuthServExtUnknownTypes, radiusAuthServTotalAccessChallenges=radiusAuthServTotalAccessChallenges, radiusAuthServResetTime=radiusAuthServResetTime, radiusAuthClientIndex=radiusAuthClientIndex, radiusAuthServBadAuthenticators=radiusAuthServBadAuthenticators, radiusAuthServExtPacketsDropped=radiusAuthServExtPacketsDropped, radiusAuthServConfigReset=radiusAuthServConfigReset, radiusAuthServMIBGroup=radiusAuthServMIBGroup, radiusAuthServTotalUnknownTypes=radiusAuthServTotalUnknownTypes, radiusAuthServUpTime=radiusAuthServUpTime, radiusAuthClientAddress=radiusAuthClientAddress, radiusAuthServExtAccessRejects=radiusAuthServExtAccessRejects, radiusAuthServDupAccessRequests=radiusAuthServDupAccessRequests, radiusAuthServPacketsDropped=radiusAuthServPacketsDropped, radiusAuthClientExtEntry=radiusAuthClientExtEntry, radiusAuthClientInetAddress=radiusAuthClientInetAddress, radiusAuthServExtMIBGroup=radiusAuthServExtMIBGroup, radiusAuthServ=radiusAuthServ, radiusAuthServMIBGroups=radiusAuthServMIBGroups, radiusAuthServMIBConformance=radiusAuthServMIBConformance, radiusAuthServMIBExtCompliance=radiusAuthServMIBExtCompliance, radiusAuthServTotalAccessAccepts=radiusAuthServTotalAccessAccepts, radiusAuthServAccessRequests=radiusAuthServAccessRequests, radiusAuthServTotalDupAccessRequests=radiusAuthServTotalDupAccessRequests, radiusAuthClientTable=radiusAuthClientTable, radiusAuthClientEntry=radiusAuthClientEntry, radiusAuthClientExtID=radiusAuthClientExtID, radiusAuthServExtBadAuthenticators=radiusAuthServExtBadAuthenticators, radiusAuthServMalformedAccessRequests=radiusAuthServMalformedAccessRequests, radiusAuthServExtDupAccessRequests=radiusAuthServExtDupAccessRequests, radiusAuthServExtAccessChallenges=radiusAuthServExtAccessChallenges, radiusMIB=radiusMIB, radiusAuthServTotalAccessRequests=radiusAuthServTotalAccessRequests, radiusAuthServAccessAccepts=radiusAuthServAccessAccepts, radiusAuthentication=radiusAuthentication, radiusAuthServIdent=radiusAuthServIdent)



#
# PySNMP MIB module CLNS-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/CLNS-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:06:59 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsUnion, ConstraintsIntersection, ValueRangeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsUnion", "ConstraintsIntersection", "ValueRangeConstraint", "SingleValueConstraint")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( Counter32, ObjectIdentity, IpAddress, TimeTicks, experimental, NotificationType, iso, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, ModuleIdentity, Unsigned32, Counter64, Gauge32, Integer32, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "ObjectIdentity", "IpAddress", "TimeTicks", "experimental", "NotificationType", "iso", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ModuleIdentity", "Unsigned32", "Counter64", "Gauge32", "Integer32", "MibIdentifier")
( TextualConvention, PhysAddress, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "PhysAddress", "DisplayString")
clns = MibIdentifier((1, 3, 6, 1, 3, 1))
class ClnpAddress(OctetString):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(1,21)

clnp = MibIdentifier((1, 3, 6, 1, 3, 1, 1))
error = MibIdentifier((1, 3, 6, 1, 3, 1, 2))
echo = MibIdentifier((1, 3, 6, 1, 3, 1, 3))
es_is = MibIdentifier((1, 3, 6, 1, 3, 1, 4)).setLabel("es-is")
clnpForwarding = MibScalar((1, 3, 6, 1, 3, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("is", 1), ("es", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpForwarding.setDescription('The indication of whether this entity is active\n                      as an intermediate or end system.  Only\n                      intermediate systems will forward PDUs onward that\n                      are not addressed to them.')
clnpDefaultLifeTime = MibScalar((1, 3, 6, 1, 3, 1, 1, 2), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpDefaultLifeTime.setDescription('The default value inserted into the Lifetime\n                      field of the CLNP PDU header of PDUs sourced by\n                      this entity.')
clnpInReceives = MibScalar((1, 3, 6, 1, 3, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInReceives.setDescription('The total number of input PDUs received from all\n                      connected network interfaces running CLNP,\n                      including errors.')
clnpInHdrErrors = MibScalar((1, 3, 6, 1, 3, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInHdrErrors.setDescription('The number of input PDUs discarded due to errors\n                      in the CLNP header, including bad checksums,\n                      version mismatch, lifetime exceeded, errors\n                      discovered in processing options, etc.')
clnpInAddrErrors = MibScalar((1, 3, 6, 1, 3, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInAddrErrors.setDescription("The number of input PDUs discarded because the\n                      NSAP address in the CLNP header's destination\n                      field was not a valid NSAP to be received at this\n                      entity.  This count includes addresses not\n                      understood.  For end systems, this is a count of\n                      PDUs which arrived with a destination NSAP which\n                      was not local.")
clnpForwPDUs = MibScalar((1, 3, 6, 1, 3, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpForwPDUs.setDescription('The number of input PDUs for which this entity\n                      was not the final destination and which an attempt\n                      was made to forward them onward.')
clnpInUnknownNLPs = MibScalar((1, 3, 6, 1, 3, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInUnknownNLPs.setDescription('The number of locally-addressed PDUs successfully\n                      received but discarded because the network layer\n                      protocol was unknown or unsupported (e.g., not\n                      CLNP or ES-IS).')
clnpInUnknownULPs = MibScalar((1, 3, 6, 1, 3, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInUnknownULPs.setDescription('The number of locally-addressed PDUs successfully\n                      received but discarded because the upper layer\n                      protocol was unknown or unsupported (e.g., not\n                      TP4).')
clnpInDiscards = MibScalar((1, 3, 6, 1, 3, 1, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInDiscards.setDescription('The number of input CLNP PDUs for which no\n                      problems were encountered to prevent their\n                      continued processing, but were discarded (e.g.,\n                      for lack of buffer space).  Note that this counter\n                      does not include any PDUs discarded while awaiting\n                      re-assembly.')
clnpInDelivers = MibScalar((1, 3, 6, 1, 3, 1, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInDelivers.setDescription('The total number of input PDUs successfully\n                      delivered to the CLNS transport user.')
clnpOutRequests = MibScalar((1, 3, 6, 1, 3, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutRequests.setDescription('The total number of CLNP PDUs which local CLNS\n                      user protocols supplied to CLNP for transmission\n                      requests.  This counter does not include any PDUs\n                      counted in clnpForwPDUs.')
clnpOutDiscards = MibScalar((1, 3, 6, 1, 3, 1, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutDiscards.setDescription('The number of output CLNP PDUs for which no other\n                      problem was encountered to prevent their\n                      transmission but were discarded (e.g., for lack of\n                      buffer space).  Note this counter includes PDUs\n                      counted in clnpForwPDUs.')
clnpOutNoRoutes = MibScalar((1, 3, 6, 1, 3, 1, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutNoRoutes.setDescription('The number of CLNP PDUs discarded because no\n                      route could be found to transmit them to their\n                      destination.  This counter includes any PDUs\n                      counted in clnpForwPDUs.')
clnpReasmTimeout = MibScalar((1, 3, 6, 1, 3, 1, 1, 14), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpReasmTimeout.setDescription('The maximum number of seconds which received\n                      segments are held while they are awaiting\n                      reassembly at this entity.')
clnpReasmReqds = MibScalar((1, 3, 6, 1, 3, 1, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpReasmReqds.setDescription('The number of CLNP segments received which needed\n                      to be reassembled at this entity.')
clnpReasmOKs = MibScalar((1, 3, 6, 1, 3, 1, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpReasmOKs.setDescription('The number of CLNP PDUs successfully re-assembled\n                      at this entity.')
clnpReasmFails = MibScalar((1, 3, 6, 1, 3, 1, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpReasmFails.setDescription('The number of failures detected by the CLNP\n                      reassembly algorithm (for any reason: timed out,\n                      buffer size, etc).')
clnpSegOKs = MibScalar((1, 3, 6, 1, 3, 1, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpSegOKs.setDescription('The number of CLNP PDUs that have been\n                      successfully segmented at this entity.')
clnpSegFails = MibScalar((1, 3, 6, 1, 3, 1, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpSegFails.setDescription('The number of CLNP PDUs that have been discarded\n                      because they needed to be fragmented at this\n                      entity but could not.')
clnpSegCreates = MibScalar((1, 3, 6, 1, 3, 1, 1, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpSegCreates.setDescription('The number of CLNP PDU segments that have been\n                      generated as a result of segmentation at this\n                      entity.')
clnpInOpts = MibScalar((1, 3, 6, 1, 3, 1, 1, 25), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInOpts.setDescription('The number of CLNP PDU segments that have been\n                      input with options at this entity.')
clnpOutOpts = MibScalar((1, 3, 6, 1, 3, 1, 1, 26), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutOpts.setDescription('The number of CLNP PDU segments that have been\n                      generated with options by this entity.')
clnpRoutingDiscards = MibScalar((1, 3, 6, 1, 3, 1, 1, 27), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpRoutingDiscards.setDescription('The number of routing entries which were chosen\n                      to be discarded even though they are valid.  One\n                      possible reason for discarding such an entry could\n                      be to free-up buffer space for other routing\n                      entries.')
clnpAddrTable = MibTable((1, 3, 6, 1, 3, 1, 1, 21), )
if mibBuilder.loadTexts: clnpAddrTable.setDescription("The table of addressing information relevant to\n                      this entity's CLNP addresses.  ")
clnpAddrEntry = MibTableRow((1, 3, 6, 1, 3, 1, 1, 21, 1), ).setIndexNames((0, "CLNS-MIB", "clnpAdEntAddr"))
if mibBuilder.loadTexts: clnpAddrEntry.setDescription("The addressing information for one of this\n                      entity's CLNP addresses.")
clnpAdEntAddr = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 21, 1, 1), ClnpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpAdEntAddr.setDescription("The CLNP address to which this entry's addressing\n                      information pertains.")
clnpAdEntIfIndex = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 21, 1, 2), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpAdEntIfIndex.setDescription('The index value which uniquely identifies the\n                      interface to which this entry is applicable.  The\n                      interface identified by a particular value of this\n                      index is the same interface as identified by the\n                      same value of ifIndex.')
clnpAdEntReasmMaxSize = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 21, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpAdEntReasmMaxSize.setDescription('The size of the largest CLNP PDU which this\n                      entity can re-assemble from incoming CLNP\n                      segmented PDUs received on this interface.')
clnpRoutingTable = MibTable((1, 3, 6, 1, 3, 1, 1, 22), )
if mibBuilder.loadTexts: clnpRoutingTable.setDescription("This entity's CLNP routing table.")
clnpRouteEntry = MibTableRow((1, 3, 6, 1, 3, 1, 1, 22, 1), ).setIndexNames((0, "CLNS-MIB", "clnpRouteDest"))
if mibBuilder.loadTexts: clnpRouteEntry.setDescription('A route to a particular destination.')
clnpRouteDest = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 1), ClnpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpRouteDest.setDescription('The destination CLNP address of this route.')
clnpRouteIfIndex = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 2), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpRouteIfIndex.setDescription('The index value which uniquely identifies the\n                      local interface through which the next hop of this\n                      route should be reached.  The interface identified\n                      by a particular value of this index is the same as\n                      identified by the same value of ifIndex.')
clnpRouteMetric1 = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 3), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpRouteMetric1.setDescription("The primary routing metric for this route.  The\n                      semantics of this metric are determined by the\n                      routing-protocol specified in the route's\n                      clnpRouteProto value.  If this metric is not used,\n                      its value should be set to -1.")
clnpRouteMetric2 = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 4), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpRouteMetric2.setDescription("An alternate routing metric for this route.  The\n                      semantics of this metric are determined by the\n                      routing-protocol specified in the route's\n                      clnpRouteProto value.  If this metric is not used,\n                      its value should be set to -1.")
clnpRouteMetric3 = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 5), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpRouteMetric3.setDescription("An alternate routing metric for this route.  The\n                      semantics of this metric are determined by the\n                      routing-protocol specified in the route's\n                      clnpRouteProto value.  If this metric is not used,\n                      its value should be set to -1.")
clnpRouteMetric4 = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 6), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpRouteMetric4.setDescription("An alternate routing metric for this route.  The\n                      semantics of this metric are determined by the\n                      routing-protocol specified in the route's\n                      clnpRouteProto value.  If this metric is not used,\n                      its value should be set to -1.")
clnpRouteNextHop = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 7), ClnpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpRouteNextHop.setDescription('The CLNP address of the next hop of this route.')
clnpRouteType = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("invalid", 2), ("direct", 3), ("remote", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpRouteType.setDescription('The type of route.\n\n                      Setting this object to the value invalid(2) has\n                      the effect of invaliding the corresponding entry\n                      in the clnpRoutingTable.  That is, it effectively\n                      dissasociates the destination identified with said\n                      entry from the route identified with said entry.\n                      It is an implementation-specific matter as to\n                      whether the agent removes an invalidated entry\n                      from the table.  Accordingly, management stations\n                      must be prepared to receive tabular information\n                      from agents that corresponds to entries not\n                      currently in use.  Proper interpretation of such\n                      entries requires examination of the relevant\n                      clnpRouteType object.')
clnpRouteProto = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 9), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 9, 11, 12, 13, 14,))).clone(namedValues=NamedValues(("other", 1), ("local", 2), ("netmgmt", 3), ("is-is", 9), ("ciscoIgrp", 11), ("bbnSpfIgp", 12), ("ospf", 13), ("bgp", 14),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpRouteProto.setDescription('The routing mechanism via which this route was\n                      learned.  Inclusion of values for gateway routing\n                      protocols is not intended to imply that hosts\n                      should support those protocols.')
clnpRouteAge = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 10), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpRouteAge.setDescription("The number of seconds since this route was last\n                      updated or otherwise determined to be correct.\n                      Note that no semantics of `too old' can be implied\n                      except through knowledge of the routing protocol\n                      by which the route was learned.")
clnpRouteMetric5 = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 11), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpRouteMetric5.setDescription("An alternate routing metric for this route.  The\n                      semantics of this metric are determined by the\n                      routing-protocol specified in the route's\n                      clnpRouteProto value.  If this metric is not used,\n                      its value should be set to -1.")
clnpRouteInfo = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 22, 1, 12), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpRouteInfo.setDescription("A reference to MIB definitions specific to the\n                      particular routing protocol which is responsible\n                      for this route, as determined by the value\n                      specified in the route's clnpRouteProto value.  If\n                      this information is not present, its value should\n                      be set to the OBJECT IDENTIFIER { 0 0 }, which is\n                      a syntatically valid object identifier, and any\n                      conformant implementation of ASN.1 and BER must be\n                      able to generate and recognize this value.")
clnpNetToMediaTable = MibTable((1, 3, 6, 1, 3, 1, 1, 23), )
if mibBuilder.loadTexts: clnpNetToMediaTable.setDescription('The CLNP Address Translation table used for\n                      mapping from CLNP addresses to physical\n                      addresses.')
clnpNetToMediaEntry = MibTableRow((1, 3, 6, 1, 3, 1, 1, 23, 1), ).setIndexNames((0, "CLNS-MIB", "clnpNetToMediaIfIndex"), (0, "CLNS-MIB", "clnpNetToMediaNetAddress"))
if mibBuilder.loadTexts: clnpNetToMediaEntry.setDescription("Each entry contains one CLNP address to\n                      `physical' address equivalence.")
clnpNetToMediaIfIndex = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 23, 1, 1), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpNetToMediaIfIndex.setDescription("The interface on which this entry's equivalence\n                      is effective.  The interface identified by a\n                      particular value of this index is the same\n                      interface as identified by the same value of\n                      ifIndex.")
clnpNetToMediaPhysAddress = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 23, 1, 2), PhysAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpNetToMediaPhysAddress.setDescription("The media-dependent `physical' address.")
clnpNetToMediaNetAddress = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 23, 1, 3), ClnpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpNetToMediaNetAddress.setDescription("The CLNP address corresponding to the media-\n                      dependent `physical' address.")
clnpNetToMediaType = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 23, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("invalid", 2), ("dynamic", 3), ("static", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpNetToMediaType.setDescription('The type of mapping.\n\n                      Setting this object to the value invalid(2) has\n                      the effect of invalidating the corresponding entry\n                      in the clnpNetToMediaTable.  That is, it\n                      effectively dissassociates the interface\n                      identified with said entry from the mapping\n                      identified with said entry.  It is an\n                      implementation-specific matter as to whether the\n                      agent removes an invalidated entry from the table.\n                      Accordingly, management stations must be prepared\n                      to receive tabular information from agents that\n                      corresponds to entries not currently in use.\n                      Proper interpretation of such entries requires\n                      examination of the relevant clnpNetToMediaType\n                      object.')
clnpNetToMediaAge = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 23, 1, 5), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpNetToMediaAge.setDescription("The number of seconds since this entry was last\n                      updated or otherwise determined to be correct.\n                      Note that no semantics of `too old' can be implied\n                      except through knowledge of the type of entry.")
clnpNetToMediaHoldTime = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 23, 1, 6), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpNetToMediaHoldTime.setDescription('The time in seconds this entry will be valid.\n                      Static entries should always report this field as\n                      -1.')
clnpMediaToNetTable = MibTable((1, 3, 6, 1, 3, 1, 1, 24), )
if mibBuilder.loadTexts: clnpMediaToNetTable.setDescription('The CLNP Address Translation table used for\n                      mapping from physical addresses to CLNP\n                      addresses.')
clnpMediaToNetEntry = MibTableRow((1, 3, 6, 1, 3, 1, 1, 24, 1), ).setIndexNames((0, "CLNS-MIB", "clnpMediaToNetIfIndex"), (0, "CLNS-MIB", "clnpMediaToNetPhysAddress"))
if mibBuilder.loadTexts: clnpMediaToNetEntry.setDescription("Each entry contains on ClnpAddress to `physical'\n                      address equivalence.")
clnpMediaToNetIfIndex = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 24, 1, 1), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpMediaToNetIfIndex.setDescription("The interface on which this entry's equivalence\n                      is effective.  The interface identified by a\n                      particular value of this index is the same\n                      interface as identified by the same value of\n                      ifIndex.")
clnpMediaToNetAddress = MibScalar((1, 3, 6, 1, 3, 1, 1, 24, 1, 2), ClnpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpMediaToNetAddress.setDescription("The ClnpAddress corresponding to the media-\n                      dependent `physical' address.")
clnpMediaToNetPhysAddress = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 24, 1, 3), PhysAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpMediaToNetPhysAddress.setDescription("The media-dependent `physical' address.")
clnpMediaToNetType = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 24, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("invalid", 2), ("dynamic", 3), ("static", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpMediaToNetType.setDescription('The type of mapping.\n\n                      Setting this object to the value invalid(2) has\n                      the effect of invalidating the corresponding entry\n                      in the clnpMediaToNetTable.  That is, it\n                      effectively dissassociates the interface\n                      identified with said entry from the mapping\n                      identified with said entry.  It is an\n                      implementation-specific matter as to whether the\n                      agent removes an invalidated entry from the table.\n                      Accordingly, management stations must be prepared\n                      to receive tabular information from agents that\n                      corresponds to entries not currently in use.\n                      Proper interpretation of such entries requires\n                      examination of the relevant clnpMediaToNetType\n                      object.')
clnpMediaToNetAge = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 24, 1, 5), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpMediaToNetAge.setDescription("The number of seconds since this entry was last\n                      updated or otherwise determined to be correct.\n                      Note that no semantics of `too old' can be implied\n                      except through knowledge of the type of entry.")
clnpMediaToNetHoldTime = MibTableColumn((1, 3, 6, 1, 3, 1, 1, 24, 1, 6), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: clnpMediaToNetHoldTime.setDescription('The time in seconds this entry will be valid.\n                      Static entries should always report this field as\n                      -1.')
clnpInErrors = MibScalar((1, 3, 6, 1, 3, 1, 2, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrors.setDescription('The number of CLNP Error PDUs received by this\n                      entity.')
clnpOutErrors = MibScalar((1, 3, 6, 1, 3, 1, 2, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrors.setDescription('The number of CLNP Error PDUs sent by this\n                      entity.')
clnpInErrUnspecs = MibScalar((1, 3, 6, 1, 3, 1, 2, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrUnspecs.setDescription('The number of unspecified CLNP Error PDUs\n                      received by this entity.')
clnpInErrProcs = MibScalar((1, 3, 6, 1, 3, 1, 2, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrProcs.setDescription('The number of protocol procedure CLNP Error PDUs\n                      received by this entity.')
clnpInErrCksums = MibScalar((1, 3, 6, 1, 3, 1, 2, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrCksums.setDescription('The number of checksum CLNP Error PDUs received\n                      by this entity.')
clnpInErrCongests = MibScalar((1, 3, 6, 1, 3, 1, 2, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrCongests.setDescription('The number of congestion drop CLNP Error PDUs\n                      received by this entity.')
clnpInErrHdrs = MibScalar((1, 3, 6, 1, 3, 1, 2, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrHdrs.setDescription('The number of header syntax CLNP Error PDUs\n                      received by this entity.')
clnpInErrSegs = MibScalar((1, 3, 6, 1, 3, 1, 2, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrSegs.setDescription('The number of segmentation disallowed CLNP Error\n                      PDUs received by this entity.')
clnpInErrIncomps = MibScalar((1, 3, 6, 1, 3, 1, 2, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrIncomps.setDescription('The number of incomplete PDU CLNP Error PDUs\n                      received by this entity.')
clnpInErrDups = MibScalar((1, 3, 6, 1, 3, 1, 2, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrDups.setDescription('The number of duplicate option CLNP Error PDUs\n                      received by this entity.')
clnpInErrUnreachDsts = MibScalar((1, 3, 6, 1, 3, 1, 2, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrUnreachDsts.setDescription('The number of unreachable destination CLNP Error\n                      PDUs received by this entity.')
clnpInErrUnknownDsts = MibScalar((1, 3, 6, 1, 3, 1, 2, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrUnknownDsts.setDescription('The number of unknown destination CLNP Error PDUs\n                      received by this entity.')
clnpInErrSRUnspecs = MibScalar((1, 3, 6, 1, 3, 1, 2, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrSRUnspecs.setDescription('The number of unspecified source route CLNP Error\n                      PDUs received by this entity.')
clnpInErrSRSyntaxes = MibScalar((1, 3, 6, 1, 3, 1, 2, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrSRSyntaxes.setDescription('The number of source route syntax CLNP Error PDUs\n                      received by this entity.')
clnpInErrSRUnkAddrs = MibScalar((1, 3, 6, 1, 3, 1, 2, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrSRUnkAddrs.setDescription('The number of source route unknown address CLNP\n                      Error PDUs received by this entity.')
clnpInErrSRBadPaths = MibScalar((1, 3, 6, 1, 3, 1, 2, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrSRBadPaths.setDescription('The number of source route bad path CLNP Error\n                      PDUs received by this entity.')
clnpInErrHops = MibScalar((1, 3, 6, 1, 3, 1, 2, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrHops.setDescription('The number of hop count exceeded CLNP Error PDUs\n                      received by this entity.')
clnpInErrHopReassms = MibScalar((1, 3, 6, 1, 3, 1, 2, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrHopReassms.setDescription('The number of hop count exceeded while\n                      reassembling CLNP Error PDUs received by this\n                      entity.')
clnpInErrUnsOptions = MibScalar((1, 3, 6, 1, 3, 1, 2, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrUnsOptions.setDescription('The number of unsupported option CLNP Error PDUs\n                      received by this entity.')
clnpInErrUnsVersions = MibScalar((1, 3, 6, 1, 3, 1, 2, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrUnsVersions.setDescription('The number of version mismatch CLNP Error PDUs\n                      received by this entity.')
clnpInErrUnsSecurities = MibScalar((1, 3, 6, 1, 3, 1, 2, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrUnsSecurities.setDescription('The number of unsupported security option CLNP\n                      Error PDUs received by this entity.')
clnpInErrUnsSRs = MibScalar((1, 3, 6, 1, 3, 1, 2, 22), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrUnsSRs.setDescription('The number of unsupported source route option\n                      CLNP Error PDUs received by this entity.')
clnpInErrUnsRRs = MibScalar((1, 3, 6, 1, 3, 1, 2, 23), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrUnsRRs.setDescription('The number of unsupported record route option\n                      CLNP Error PDUs received by this entity.')
clnpInErrInterferences = MibScalar((1, 3, 6, 1, 3, 1, 2, 24), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpInErrInterferences.setDescription('The number of reassembly interference CLNP Error\n                      PDUs received by this entity.')
clnpOutErrUnspecs = MibScalar((1, 3, 6, 1, 3, 1, 2, 25), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrUnspecs.setDescription('The number of unspecified CLNP Error PDUs sent by\n                      this entity.')
clnpOutErrProcs = MibScalar((1, 3, 6, 1, 3, 1, 2, 26), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrProcs.setDescription('The number of protocol procedure CLNP Error PDUs\n                      sent by this entity.')
clnpOutErrCksums = MibScalar((1, 3, 6, 1, 3, 1, 2, 27), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrCksums.setDescription('The number of checksum CLNP Error PDUs sent by\n                      this entity.')
clnpOutErrCongests = MibScalar((1, 3, 6, 1, 3, 1, 2, 28), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrCongests.setDescription('The number of congestion drop CLNP Error PDUs\n                      sent by this entity.')
clnpOutErrHdrs = MibScalar((1, 3, 6, 1, 3, 1, 2, 29), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrHdrs.setDescription('The number of header syntax CLNP Error PDUs sent\n                      by this entity.')
clnpOutErrSegs = MibScalar((1, 3, 6, 1, 3, 1, 2, 30), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrSegs.setDescription('The number of segmentation disallowed CLNP Error\n                      PDUs sent by this entity.')
clnpOutErrIncomps = MibScalar((1, 3, 6, 1, 3, 1, 2, 31), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrIncomps.setDescription('The number of incomplete PDU CLNP Error PDUs sent\n                      by this entity.')
clnpOutErrDups = MibScalar((1, 3, 6, 1, 3, 1, 2, 32), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrDups.setDescription('The number of duplicate option CLNP Error PDUs\n                      sent by this entity.')
clnpOutErrUnreachDsts = MibScalar((1, 3, 6, 1, 3, 1, 2, 33), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrUnreachDsts.setDescription('The number of unreachable destination CLNP Error\n                      PDUs sent by this entity.')
clnpOutErrUnknownDsts = MibScalar((1, 3, 6, 1, 3, 1, 2, 34), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrUnknownDsts.setDescription('The number of unknown destination CLNP Error PDUs\n                      sent by this entity.')
clnpOutErrSRUnspecs = MibScalar((1, 3, 6, 1, 3, 1, 2, 35), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrSRUnspecs.setDescription('The number of unspecified source route CLNP Error\n                      PDUs sent by this entity.')
clnpOutErrSRSyntaxes = MibScalar((1, 3, 6, 1, 3, 1, 2, 36), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrSRSyntaxes.setDescription('The number of source route syntax CLNP Error PDUs\n                      sent by this entity.')
clnpOutErrSRUnkAddrs = MibScalar((1, 3, 6, 1, 3, 1, 2, 37), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrSRUnkAddrs.setDescription('The number of source route unknown address CLNP\n                      Error PDUs sent by this entity.')
clnpOutErrSRBadPaths = MibScalar((1, 3, 6, 1, 3, 1, 2, 38), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrSRBadPaths.setDescription('The number of source route bad path CLNP Error\n                      PDUs sent by this entity.')
clnpOutErrHops = MibScalar((1, 3, 6, 1, 3, 1, 2, 39), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrHops.setDescription('The number of hop count exceeded CLNP Error PDUs\n                      sent by this entity.')
clnpOutErrHopReassms = MibScalar((1, 3, 6, 1, 3, 1, 2, 40), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrHopReassms.setDescription('The number of hop count exceeded while\n                      reassembling CLNP Error PDUs sent by this entity.')
clnpOutErrUnsOptions = MibScalar((1, 3, 6, 1, 3, 1, 2, 41), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrUnsOptions.setDescription('The number of unsupported option CLNP Error PDUs\n                      sent by this entity.')
clnpOutErrUnsVersions = MibScalar((1, 3, 6, 1, 3, 1, 2, 42), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrUnsVersions.setDescription('The number of version mismatch CLNP Error PDUs\n                      sent by this entity.')
clnpOutErrUnsSecurities = MibScalar((1, 3, 6, 1, 3, 1, 2, 43), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrUnsSecurities.setDescription('The number of unsupported security option CLNP\n                      Error PDUs sent by this entity.')
clnpOutErrUnsSRs = MibScalar((1, 3, 6, 1, 3, 1, 2, 44), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrUnsSRs.setDescription('The number of unsupported source route option\n                      CLNP Error PDUs sent by this entity.')
clnpOutErrUnsRRs = MibScalar((1, 3, 6, 1, 3, 1, 2, 45), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrUnsRRs.setDescription('The number of unsupported record route option\n                      CLNP Error PDUs sent by this entity.')
clnpOutErrInterferences = MibScalar((1, 3, 6, 1, 3, 1, 2, 46), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: clnpOutErrInterferences.setDescription('The number of reassembly interference CLNP Error\n                      PDUs sent by this entity.')
esisESHins = MibScalar((1, 3, 6, 1, 3, 1, 4, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: esisESHins.setDescription('The number of ESH PDUs received by this entity.')
esisESHouts = MibScalar((1, 3, 6, 1, 3, 1, 4, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: esisESHouts.setDescription('The number of ESH PDUs sent by this entity.')
esisISHins = MibScalar((1, 3, 6, 1, 3, 1, 4, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: esisISHins.setDescription('The number of ISH PDUs received by this entity.')
esisISHouts = MibScalar((1, 3, 6, 1, 3, 1, 4, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: esisISHouts.setDescription('The number of ISH PDUs sent by this entity.')
esisRDUins = MibScalar((1, 3, 6, 1, 3, 1, 4, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: esisRDUins.setDescription('The number of RDU PDUs received by this entity.')
esisRDUouts = MibScalar((1, 3, 6, 1, 3, 1, 4, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: esisRDUouts.setDescription('The number of RDU PDUs sent by this entity.')
mibBuilder.exportSymbols("CLNS-MIB", clnpNetToMediaTable=clnpNetToMediaTable, clnpSegCreates=clnpSegCreates, clnpRouteNextHop=clnpRouteNextHop, clnpRouteMetric5=clnpRouteMetric5, echo=echo, clnpNetToMediaNetAddress=clnpNetToMediaNetAddress, clnpInErrSRUnkAddrs=clnpInErrSRUnkAddrs, clnpMediaToNetType=clnpMediaToNetType, clnpOutErrUnsOptions=clnpOutErrUnsOptions, clnpOutNoRoutes=clnpOutNoRoutes, clnpInErrProcs=clnpInErrProcs, clnpRouteIfIndex=clnpRouteIfIndex, clnpInUnknownULPs=clnpInUnknownULPs, clnpNetToMediaEntry=clnpNetToMediaEntry, clnpOutErrUnspecs=clnpOutErrUnspecs, clnpOutErrIncomps=clnpOutErrIncomps, esisRDUins=esisRDUins, clnpRouteEntry=clnpRouteEntry, clnpInUnknownNLPs=clnpInUnknownNLPs, clnpOutErrHops=clnpOutErrHops, clnpAddrEntry=clnpAddrEntry, clnpOutErrUnsSRs=clnpOutErrUnsSRs, clnpOutErrUnsSecurities=clnpOutErrUnsSecurities, esisISHins=esisISHins, ClnpAddress=ClnpAddress, error=error, esisESHouts=esisESHouts, clnpInErrUnsSRs=clnpInErrUnsSRs, clnpRouteMetric2=clnpRouteMetric2, clnpRouteAge=clnpRouteAge, clnpNetToMediaIfIndex=clnpNetToMediaIfIndex, clnpRouteMetric3=clnpRouteMetric3, clnpReasmReqds=clnpReasmReqds, clnpOutErrUnreachDsts=clnpOutErrUnreachDsts, clnpRouteProto=clnpRouteProto, clnpReasmTimeout=clnpReasmTimeout, clnpInOpts=clnpInOpts, clnpOutErrSRBadPaths=clnpOutErrSRBadPaths, clnpOutErrSRSyntaxes=clnpOutErrSRSyntaxes, clnpForwarding=clnpForwarding, clnpMediaToNetAge=clnpMediaToNetAge, clnpMediaToNetEntry=clnpMediaToNetEntry, clnpInErrUnknownDsts=clnpInErrUnknownDsts, clnpOutErrProcs=clnpOutErrProcs, clnpAddrTable=clnpAddrTable, clnpInErrUnsSecurities=clnpInErrUnsSecurities, esisESHins=esisESHins, clnpNetToMediaType=clnpNetToMediaType, clnpNetToMediaAge=clnpNetToMediaAge, clnpOutErrUnsRRs=clnpOutErrUnsRRs, clnpMediaToNetHoldTime=clnpMediaToNetHoldTime, clnpInErrUnspecs=clnpInErrUnspecs, clnpForwPDUs=clnpForwPDUs, clnpAdEntAddr=clnpAdEntAddr, clnpInErrHops=clnpInErrHops, clnpMediaToNetAddress=clnpMediaToNetAddress, clnpInDelivers=clnpInDelivers, clnpAdEntReasmMaxSize=clnpAdEntReasmMaxSize, clnpSegOKs=clnpSegOKs, clnpRouteMetric1=clnpRouteMetric1, clnpInErrors=clnpInErrors, clnpInErrSRUnspecs=clnpInErrSRUnspecs, clnpReasmOKs=clnpReasmOKs, clnpInHdrErrors=clnpInHdrErrors, clnpOutRequests=clnpOutRequests, clnpNetToMediaHoldTime=clnpNetToMediaHoldTime, clnpInErrHopReassms=clnpInErrHopReassms, clnpInErrHdrs=clnpInErrHdrs, clnpInAddrErrors=clnpInAddrErrors, clnpInErrUnsOptions=clnpInErrUnsOptions, clnpOutErrHdrs=clnpOutErrHdrs, clnpOutErrSegs=clnpOutErrSegs, clnpInErrInterferences=clnpInErrInterferences, clnpOutErrSRUnkAddrs=clnpOutErrSRUnkAddrs, clnpInErrIncomps=clnpInErrIncomps, clnpMediaToNetTable=clnpMediaToNetTable, clnpOutErrCongests=clnpOutErrCongests, clnpOutErrors=clnpOutErrors, clnpOutOpts=clnpOutOpts, clnpOutDiscards=clnpOutDiscards, clnpRouteDest=clnpRouteDest, es_is=es_is, clnpOutErrUnsVersions=clnpOutErrUnsVersions, clnpOutErrHopReassms=clnpOutErrHopReassms, clnpRouteMetric4=clnpRouteMetric4, clnpInErrSRBadPaths=clnpInErrSRBadPaths, clnpReasmFails=clnpReasmFails, clnpDefaultLifeTime=clnpDefaultLifeTime, clnpMediaToNetPhysAddress=clnpMediaToNetPhysAddress, esisISHouts=esisISHouts, clnpMediaToNetIfIndex=clnpMediaToNetIfIndex, clns=clns, clnpInErrCongests=clnpInErrCongests, esisRDUouts=esisRDUouts, clnpInErrDups=clnpInErrDups, clnpNetToMediaPhysAddress=clnpNetToMediaPhysAddress, clnpSegFails=clnpSegFails, clnpInErrUnsRRs=clnpInErrUnsRRs, clnpInErrSRSyntaxes=clnpInErrSRSyntaxes, clnpInErrCksums=clnpInErrCksums, clnpAdEntIfIndex=clnpAdEntIfIndex, clnpInErrSegs=clnpInErrSegs, clnpRouteInfo=clnpRouteInfo, clnpRouteType=clnpRouteType, clnpOutErrCksums=clnpOutErrCksums, clnpRoutingDiscards=clnpRoutingDiscards, clnpOutErrInterferences=clnpOutErrInterferences, clnpOutErrDups=clnpOutErrDups, clnpRoutingTable=clnpRoutingTable, clnpOutErrSRUnspecs=clnpOutErrSRUnspecs, clnpInErrUnsVersions=clnpInErrUnsVersions, clnpOutErrUnknownDsts=clnpOutErrUnknownDsts, clnpInErrUnreachDsts=clnpInErrUnreachDsts, clnpInReceives=clnpInReceives, clnpInDiscards=clnpInDiscards, clnp=clnp)
